#Isopleth contour mapping function for dissolved oxygen or temperature in lakes

#Authors: Mark E. Swanson and Cascade Herriott
#Modified by Andrew W. Child to create tiff at 300dpi and incorporate more dates
#Version Date: Jan 21, 2015

#Version 4.4

#Writes a function called 'lake.fun' that automates output of isopleth graphs
#for depth X time data saved in CSV (comma-separated values) format.  	
#Includes options for window size manipulation. See example at end of code.  	

#Input data formatting:
	#Upper left cell left blank, delete "depth (m)" if present
	#If there are too many NA values at the bottom of the file it 	may not interpolate. Thus, if needed trim bottom depths off 	to remove NA strings  
	#Columns: dates ascending, left to right
	#Rows: measurements for each depth (descending top to bottom)
	#Note change in date formats: please enter dates as Julian dates (0-365). 	
#Set working directory to location of your files
	#Helpful to save all of your documents in one folder
	#To set working directory, go to R console, and then select 'File' > 'Change dir...'
	#To set working directory, modify code in next line, and type 'Ctrl-R'
#Input arguments:
	#'csvname' is the name of the file containing your formatted data.
		#Data must be in CSV (comma-separated values) format ("Save as..." in Excel)
		#Enter in quotes ("")
		#Example of name: "my_data.csv"
	#'lake.title' is a character string for the main title
		#Enter in quotes ("")
	#'type' is the type of data: 
		# Enter in quotes ("")
			# "temp" for temperature
			# "ox" for oxygen

#Begin code: 
setwd()

#Begin function: 
lake.fun<-function(csvname,lake.title,type,out,w=12.625,h=6.18) {
csvdata<-read.csv(csvname,
				header=F,
				na.string=c("","NA","-","<DL"))

names(csvdata)<-c("depth",paste("date",1:(ncol(csvdata)-1),sep=""))
depth.lab<-if(nrow(csvdata)>15) seq(0,max(csvdata$depth,na.rm=T),4) else csvdata$depth[2:length(csvdata$depth)]
depth<-csvdata$depth[2:length(csvdata$depth)]

#Transpose matrix
z<-t(as.matrix(csvdata[,2:ncol(csvdata)]))
dim(z)

#Format transpose matrix
z[,1]->julian.date				#Extract string of Julian dates
z<-z[,2:ncol(z)]				#Remove Julian date column
dim(z)

#Interpolation
#Generate nearest included multiples of 5 for Julian dates
in.dates<-seq(min(julian.date)+(5-(min(julian.date)%%5)),
		max(julian.date)-(max(julian.date)%%5),
		5)

#Optional sequence for the graphed date range (Mar-Mar)
#Remove '#' in front of following line of code to enable.  
in.dates<-seq(56,445,5)

#Run interpolation on each sequence, coercing to desired interval.
z2<-data.frame()
for(i in 1:ncol(z)){
z2[1:length(in.dates),i]<-approx(julian.date,z[,i],xout=in.dates)[2]
}

#z2 now has depth across columns, and time (Julian) across rows
#z2 will be plot data

#Julian month labels
month.in<-c(015,046,074,105,135,166,196,227,258,288,319,349,380,411,439)
month.txt<-c("Jan","Feb","Mar","Apr","May","Jun",
			"Jul","Aug","Sep","Oct","Nov","Dec","Jan","Feb","Mar")

#Adjust color levels to data type
g.val<-	switch(type, 
			 temp=seq(0,30,1), 
			 do=seq(0,15,1))

#Key titles
key.lab<-switch(type,
		    temp="Deg. C",
		    do="mg/L")

#create tiff at 300dpi, remember to name your file correctly, and turn off your device=dev.off()
#if you only want to preview the isopleth you have to toggle the following lines and untoggle quartz
dpi<-300
tiff(out,width=11.25*dpi,height=6*dpi,res=dpi)

#Graphing commands
#quartz(w,h)
#filled.contour(in.dates,1:ncol(z2),as.matrix(z2[,ncol(z2):1]),		
								#number of columns in z for third argument
	filled.contour(in.dates,depth,as.matrix(z2),
	ylim=rev(range(depth)),
	family="Helvetica",
	main=lake.title,	
	xlab=NULL,
	ylab="Depth (m)",
	font.lab=2,
	cex.lab=1.4,
	key.title=title(key.lab),
	levels = g.val,
	col= gray(seq(1,0.5,len=length(g.val+1))),
	plot.axes={
	axis(1,cex.axis=1.5,at=month.in,as.character(month.txt));	
	axis(2,cex.axis=1.5,at=depth.lab,depth.lab);
	axis(2,cex.axis=1.5,at=csvdata$depth[1:nrow(csvdata)],tick=T,labels=FALSE);
	 contour(in.dates,depth,as.matrix(z2),
	 ylim=rev(range(depth)),
        levels = g.val, drawlabels = TRUE,labcex = 1.4,   		#levels set to integers      
		add = TRUE)		
			}
	)
}					#End of 'lake.fun'function

#Figures isopleths

  #Newman Lake
    lake.fun("NEW_MID_DO.csv","","do","Fig1a.tiff")
    dev.off()
  #North Twin Lake
    lake.fun("NT_MID_DO.csv","","do","Fig2a.tiff")
    dev.off()
  #South Twin Lake
    lake.fun("ST_MID_DO.csv","","do","Fig3a.tiff")
    dev.off()